@@ -1,4 +1,5 @@
 /*  backend.h
+ *  vim:ts=4:sw=4:noexpandtab:cindent
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -60,8 +61,13 @@ typedef struct
 	char *hwaddr;
 	char *ptpip;
 	char *ipv6;
+	char *essid;
 	gboolean up, running;
 	guint64 tx, rx;
+	int qual;
+	char *tx_rate;
+	char *rx_rate;
+	char *sum_rate;
 } DevInfo;
 
 GList*
@@ -71,7 +77,7 @@ const gchar*
 get_default_route(void);
 
 gboolean
-is_no_dummy_device(const char* device);
+is_dummy_device(const char* device);
 
 void
 free_devices_list(GList *list);
@@ -85,4 +91,6 @@ get_device_info(const char *device, DevInfo *info);
 gboolean
 compare_device_info(const DevInfo *a, const DevInfo *b);
 
+void 
+get_wireless_info (DevInfo *devinfo);
 #endif /* _BACKEND_H */
