@@ -1,4 +1,5 @@
- /*  netspeed.c
+/*  netspeed.c
+ *  vim:ts=4:sw=4:noexpandtab:cindent
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -351,9 +352,8 @@ update_quality_icon(NetspeedApplet *applet)
 	unsigned int q;
 	
 	q = (applet->devinfo.qual);
-	q = logf (q / 3.0f) + 0.25f;
-
-	g_assert(q >= 0 && q < 4);
+	q /= 25;
+	q = CLAMP(q, 0, 3); /* q out of range would crash when accessing qual_pixbufs[q] */
 	gtk_image_set_from_pixbuf (GTK_IMAGE(applet->qual_pix), applet->qual_pixbufs[q]);
 }
 
@@ -377,8 +377,10 @@ init_quality_pixbufs(NetspeedApplet *applet)
 static void
 icon_theme_changed_cb(GtkIconTheme *icon_theme, gpointer user_data)
 {
+    NetspeedApplet *applet = (NetspeedApplet*)user_data;
     init_quality_pixbufs(user_data);
-    update_quality_icon(user_data);
+    if (applet->devinfo.type == DEV_WIRELESS && applet->devinfo.up)
+        update_quality_icon(user_data);
     change_icons(user_data);
 }    
 
@@ -463,18 +465,18 @@ redraw_graph(NetspeedApplet *applet)
 	
 	/* calculate the polygons (GdkPoint[]) for the graphs */ 
 	offset = 0;
-	for (i = applet->index_graph + 1; applet->in_graph[i] < 0; i = (i + 1) % GRAPH_VALUES)
+	for (i = (applet->index_graph + 1) % GRAPH_VALUES; applet->in_graph[i] < 0; i = (i + 1) % GRAPH_VALUES)
 		offset++;
 	for (i = offset + 1; i < GRAPH_VALUES; i++)
 	{
 		int index = (applet->index_graph + i) % GRAPH_VALUES;
-		out_points[i].x = in_points[i].x = ((w - 8) * i) / GRAPH_VALUES + 2;
+		out_points[i].x = in_points[i].x = ((w - 6) * i) / GRAPH_VALUES + 4;
 		in_points[i].y = h - 6 - (int)((h - 8) * applet->in_graph[index] / max_val);
 		out_points[i].y = h - 6 - (int)((h - 8) * applet->out_graph[index] / max_val);
 	}	
-	in_points[offset].x = out_points[offset].x = ((w - 8) * offset) / GRAPH_VALUES + 2;
-	in_points[offset].y = in_points[offset + 1].y;
-	out_points[offset].y = out_points[offset + 1].y;
+	in_points[offset].x = out_points[offset].x = ((w - 6) * offset) / GRAPH_VALUES + 4;
+	in_points[offset].y = in_points[(offset + 1) % GRAPH_VALUES].y;
+	out_points[offset].y = out_points[(offset + 1) % GRAPH_VALUES].y;
 	
 	/* draw the background */
 	gdk_gc_set_rgb_fg_color (gc, &da->style->black);
@@ -833,7 +835,7 @@ about_cb(BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 	
 	gtk_show_about_dialog (NULL, 
 			       "version", VERSION, 
-			       "copyright", "Copyright 2002 - 2003 Jörgen Scheibengruber",
+			       "copyright", "Copyright 2002 - 2010 Jörgen Scheibengruber",
 			       "comments", _("A little applet that displays some information on the traffic on the specified network device"),
 			       "authors", authors, 
 			       "documenters", NULL, 
@@ -1022,7 +1024,7 @@ settings_cb(BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 	/* Default means device with default route set */
 	gtk_combo_box_append_text(GTK_COMBO_BOX(applet->network_device_combo), _("Default"));
 	ptr = devices = get_available_devices();
-	for (i = 0; ptr; ptr = g_list_next(ptr)) {
+	for (i = 1; ptr; ptr = g_list_next(ptr)) {
 		gtk_combo_box_append_text(GTK_COMBO_BOX(applet->network_device_combo), ptr->data);
 		if (g_str_equal(ptr->data, applet->devinfo.name)) active = i;
 		++i;
@@ -1244,7 +1246,7 @@ showinfo_cb(BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 	if (applet->devinfo.ipv6 && (strlen (applet->devinfo.ipv6) > 2)) {
 		GtkWidget *ipv6_label, *ipv6_text;
 
-		ipv6_label = gtk_label_new (_("IPV6 Address:"));
+		ipv6_label = gtk_label_new (_("IPv6 Address:"));
 		ipv6_text = gtk_label_new (applet->devinfo.ipv6);
 		
 		gtk_label_set_selectable (GTK_LABEL (ipv6_text), TRUE);
@@ -1358,26 +1360,26 @@ applet_button_press(GtkWidget *widget, GdkEventButton *event, NetspeedApplet *ap
 		
 		if (applet->up_cmd && applet->down_cmd)
 		{
-			char *question;
+			const char *question;
 			int response;
 			
 			if (applet->devinfo.up) 
 			{
-				question = g_strdup_printf(_("Do you want to disconnect %s now?"), applet->devinfo.name); 
+				question = _("Do you want to disconnect %s now?");
 			} 
 			else
 			{
-				question = g_strdup_printf(_("Do you want to connect %s now?"), applet->devinfo.name);
+				question = _("Do you want to connect %s now?");
 			}
 			
 			applet->connect_dialog = gtk_message_dialog_new(NULL, 
 					GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 					GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO,
-					question);
+					question,
+					applet->devinfo.name);
 			response = gtk_dialog_run(GTK_DIALOG(applet->connect_dialog));
 			gtk_widget_destroy (applet->connect_dialog);
 			applet->connect_dialog = NULL;
-			g_free(question);
 			
 			if (response == GTK_RESPONSE_YES)
 			{
@@ -1390,9 +1392,11 @@ applet_button_press(GtkWidget *widget, GdkEventButton *event, NetspeedApplet *ap
 
 				if (!g_spawn_command_line_async(command, &error))
 				{
-					dialog = gtk_message_dialog_new(NULL, 
+					dialog = gtk_message_dialog_new_with_markup(NULL, 
 							GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 							GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
+							_("<b>Running command %s failed</b>\n%s"),
+							command,
 							error->message);
 					gtk_dialog_run (GTK_DIALOG (dialog));
 					gtk_widget_destroy (dialog);
@@ -1412,8 +1416,14 @@ applet_button_press(GtkWidget *widget, GdkEventButton *event, NetspeedApplet *ap
 static void
 applet_destroy(PanelApplet *applet_widget, NetspeedApplet *applet)
 {
+	GtkIconTheme *icon_theme;
+	
 	g_assert(applet);
 	
+	icon_theme = gtk_icon_theme_get_default();
+	g_object_disconnect(G_OBJECT(icon_theme), "changed",
+			G_CALLBACK(icon_theme_changed_cb), (gpointer)applet,
+			NULL);
 	g_source_remove(applet->timeout_id);
 	applet->timeout_id = 0;
 	
